Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(914)

Unified Diff: ui/gfx/color_profile.h

Issue 1796293003: Image decode color: Push color profile from browser to renderer (Closed) Base URL: https://chromium.googlesource.com/chromium/src.git@master
Patch Set: Fix windows tests Created 4 years, 9 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: ui/gfx/color_profile.h
diff --git a/ui/gfx/color_profile.h b/ui/gfx/color_profile.h
index 7bd5d443eccb2315b911bc3e85817aad67043a88..dfbea5742b21ab54aa6cde2612006268e4e60bba 100644
--- a/ui/gfx/color_profile.h
+++ b/ui/gfx/color_profile.h
@@ -22,8 +22,7 @@ static const size_t kMaxProfileLength = 4 * 1024 * 1024;
class GFX_EXPORT ColorProfile {
public:
- // On Windows, this reads a file from disk so it should not be run on the UI
- // or IO thread.
+ // Creates a color profile for the system's primary monitor.
ccameron 2016/03/15 06:02:24 This should be a function called GetPrimaryDisplay
ColorProfile();
~ColorProfile();
@@ -39,10 +38,17 @@ inline bool InvalidColorProfileLength(size_t length) {
return (length < kMinProfileLength) || (length > kMaxProfileLength);
}
-// Return the color profile of the display nearest the screen bounds. On Win32,
-// this may read a file from disk so it should not be run on the UI/IO threads.
-// If the given bounds are empty, or are off-screen, return false meaning there
-// is no color profile associated with the bounds. Otherwise return true after
+#if defined(OS_WIN)
+// On Windows, color profile data is read from a file on disk, which may take an
+// arbitrarily long time to run. This function will update all displays' color
+// profiles. It should not be called on the UI or IO threads. The functions to
+// query color profiles will read the data cached by this function.
+void GFX_EXPORT UpdateDisplayColorProfileCache();
+#endif
+
+// Return the color profile of the display nearest the screen bounds. If the
+// given bounds are empty, or are off-screen, return false meaning there is no
+// color profile associated with the bounds. Otherwise return true after
// storing the display's color profile in |profile|, which will be empty if the
// standard sRGB color profile should be assumed.
GFX_EXPORT bool GetDisplayColorProfile(const gfx::Rect& bounds,

Powered by Google App Engine
This is Rietveld 408576698